def pstar(n,c):


   for i in range(1,n+1):

      if bool(c)==True:
        print("*"*i)

      else:
        print("*"*(n+1-i))  

def phash(n,c):


   for i in range(1,n+1):

      if bool(c)==True:
        print("*"*i)

      else:
        print("#"*(n+1-i))  

def pdoller(n,c):


   for i in range(1,n+1):

      if bool(c)==True:
        print("$"*i)

      else:
        print("$"*(n+1-i))  

def pat(n,c):


   for i in range(1,n+1):

      if bool(c)==True:
        print("@"*i)

      else:
        print("@"*(n+1-i))  


                             


   




from setuptools import setup

def readme():
    with open('readme.md') as f:
        readme = f.read()
    return readme


setup( name="triprint",
     version="1.0.5",
     description="This package is created by Vikrant Singh. This package is used for printing '*' or '#' triangles for desired number of rows.",
     author_email="vikrants298@gmail.com",
     url="https://github.com/vikrantsingh298/Vikrant-s-Stuff/blob/master/triangle_print.py",
     long_description=readme(),
     long_description_content_type="text/markdown",
     author="Vikrant Singh",
     packages=['triprint'],
     install_requires=[ ],
     license="MIT",
     include_package_data=True,
)